@@ -320,7 +320,7 @@
 #define HAVE_GETUID
 #endif
 #ifndef HAVE_I_SETSIG
-#define HAVE_I_SETSIG
+/* #undef HAVE_I_SETSIG */
 #endif
 
 /**
